@@ -2,7 +2,7 @@
 # the next line restarts using the interpreter \
 exec tclsh "$0" "$@"
 
-# $Id: instapkg.tcl,v 1.3 1997/10/25 19:47:03 jfontain Exp $
+# $Id: instapkg.tcl,v 1.4 1998/04/03 06:13:22 jfontain Exp $
 
 if {[llength $argv]!=1} {
     puts stderr "usage: $argv0 directory"
@@ -22,10 +22,14 @@ if {![file exists $directory]} {
     exit 1
 }
 
-if {[catch {package require stooop 3.0} message]} {
+if {[catch {package require stooop 3.4} message]} {
     puts stderr "stooop package must be installed first: $message"
     exit 1
 }
+if {[catch {package require switched 1.4} message]} {
+    puts stderr "switched package must be installed first: $message"
+    exit 1
+}
 
 if {[catch {eval file copy -force {pkgIndex.tcl util.tcl pielabel.tcl perilabel.tcl boxlabel.tcl canlabel.tcl labarray.tcl slice.tcl pie.tcl} {$directory}} message]} {
     puts stderr $message
